@@ -54,7 +54,7 @@ download.TD.data <- function(asset.codes = 'LTN',
 
   # check if names names sense
 
-  possible.names <- c("LFT","LTN","NTN-C","NTN-B","NTN-B Principal","NTN-F")
+  possible.names <- get_td_names()
   if (!is.null(asset.codes)){
 
     idx <- asset.codes %in% possible.names
